@@ -1,11 +1,11 @@
 package Gearman::Client;
-$Gearman::Client::VERSION = '1.12.006';
+$Gearman::Client::VERSION = '1.12.007';
 
 use strict;
 use warnings;
 no warnings "redefine";
 
-use base 'Gearman::Base';
+use base 'Gearman::Object';
 
 use fields (
     'sock_cache',    # hostport -> socket
